#
# spec file for package cage
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cage
Version:        0.2.0+0.e128a9f
Release:        1.3
Summary:        Wayland Kiosk
License:        MIT
Group:          System/GUI/Other
URL:            https://www.hjdskes.nl/projects/cage/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  meson >= 0.43.0
BuildRequires:  pkgconfig
BuildRequires:  scdoc
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.14
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(wlroots-0.18) >= 0.18.0
BuildRequires:  pkgconfig(xkbcommon)

%description
A Wayland Kiosk.

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%{_bindir}/cage
%{_mandir}/man1/cage.1%{?ext_man}

%changelog
* Mon Oct  7 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Fix name for BuildRequire of wlroots
  * wlroots is very explicit with versions. It now has a suffix added based
    version format <major>.<minor> i.e. wlroots-0.18 to refer to the 0.18.x
    series
* Mon Oct  7 2024 mvetter@suse.com
- Update to version 0.2.0+0.e128a9f:
  * build: bump to version 0.2.0
  * ci: drop libwayland C23 workaround
  * xdg_shell: wait for initial commit to unconstrain popups
  * cage: fix abort on shutdown
  * xdg_shell: wait for initial commit to set xdg-decoration mode
  * xdg_shell: configure surface on initial commit
  * ci: workaround libwayland C23 bug
  * seat: rename WLR_INPUT_DEVICE_TABLET_TOOL to WLR_INPUT_DEVICE_TABLET
  * xdg_shell: use new lifecycle events
  * cage: drop wlr_scene_set_presentation()
  * cage: create backend with wl_event_loop and output layout with wl_display
  * seat: pass relative direction to wlr_seat_pointer_notify_axis()
  * Bump wlroots requirement to v0.18
  * cage: fix SIGINT/SIGTERM handler data
  * ci: turn on --fatal-meson-warnings
  * readme: update meson commands
  * readme: update wlroots dependency version
  * build: drop xwayland option
* Tue Aug 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Cleanup up _service:
  + tar and compress services should be 'buildtime' in combination
    with obs_scm.
  + Remove the .tar.xz tarball, only eep the .obscpio archive as
    source.
  + Drop stale cage-0.1.5+0.83ffc57.obscpio archive, add
    cage-0.1.5+36.e7d8780.obscpio instead: This is the same version
    as previously packages as tar.xz.
* Tue Aug 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(wlroots) instead of wlroots-devel: ensure
  we get a devel package that has the correct .pc file (latest
  wlroots has the pc file renamed to wlroots-0.18.pc, not matching
  the name anymore).
* Thu Mar 21 2024 mvetter@suse.com
- Update repo URL
- Switch to git e7d8780 to fix build with wlroots
- Add changesgenerate to service file
- Switch from disabled to manual service
- Update to version 0.1.5+36.e7d8780:
  * Add support for primary selection
  * Add .editorconfig
  * output: fix assert when re-adding output to layout
  * output: use wlr_output_head_v1_state_apply()
  * xwayland: fix double wl_list_remove
  * output: Transition to wlr_output_state
  * output: Add scene output layout helper manually
  * output: Implement request_state event listener
  * meson: Bump minimum wlroots to 0.17
  * ci: Upgrade wlroots to 0.17
* Mon Jul 31 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.1.5:
  * Implement the following protocols: wlr-output-management-unstable-v1,
    virtual-keyboard-unstable-v1, wlr-virtual-pointer-unstable-v1,
    single-pixel-buffer-v1, presentation-time, viewporter.
  * Use wlroots' scene-graph API, which should improve performance.
  * Fall back to lower resolutions when the preferred output
    mode cannot be used.
- Drop cage-wlroots-016-compat.patch
* Thu Dec  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.1.4+39.a81ab70
  We asked in https://github.com/Hjdskes/cage/issues/232
  for a long time for a wlroots 0.15.0 compat release
  * Compatibility with wlroots 0.15.0
  * Fix count_surface_iterator
  * Set xdg_toplevel geometry for fullscreen clients
  * Restore direct libm dependency (#222)
  * Several more fixes
- Add cage-wlroots-016-compat.patch:
  Add compat with wlroots 0.16.0. See PR 244.
- Switch to service file to generate tarball
* Sun Jun 27 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4:
  * Compatibility release to track wlroots 0.14.0
- Drop cage-wlroots-0140.patch: upstreamed
* Thu Jun 24 2021 Michael Vetter <mvetter@suse.com>
- Add cage-wlroots-0140.patch: make compatible with wlroots 0.14.0
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.1.3:
  * compatibility release to track wlroots 0.13.0
* Thu Jul 16 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.1.2.1:
  * man: indent with tabs (#156)
* Thu Jul 16 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.1.2:
  * Cage now implements the
    wlr-screencopy-unstable-v1,
    xdg-output-unstable-v1.xml,
    wlr-gamma-control-unstable-v1,
    and wlr_export_dmabuf_unstable_v1 protocols.
  * Support for direct scan-out has been added to Cage.
  * Cage now allows switching VTs
  * Extended multi monitor behaviour
    One to extend the application across the monitors' bounding
    box and another to use only the last plugged in monitor.
  * Add support for keyboard groups.
  * Cage now comes with a manpage
  * For details see https://github.com/Hjdskes/cage/releases/tag/v0.1.2
- Remove because in new release:
  * cage-0.1.1-new-wlroots.patch
  * cage-0.1.1-dont-terminate-display.patch
* Thu Apr  2 2020 Michael Vetter <mvetter@suse.com>
- Add cage-0.1.1-dont-terminate-display.patch: dont terminate display
  Some applications wont work correctly otherwise.
* Thu Jan 23 2020 Michael Vetter <mvetter@suse.com>
- Add cage-0.1.1-new-wlroots.patch: make it work with newer wlroots
* Tue Jun  4 2019 mvetter@suse.com
- Update to 1.1.1:
  * Update to wlroots 0.6.0
  * Cage: drop root on startup like Sway
* Wed Apr 24 2019 mvetter@suse.com
- Initial package for cage 0.1
